@@ -8,7 +8,7 @@
         res = method.execute(sql='select * from user', fetchone=True, back_dict=True)
 """
 from gtoolkit.db.orm.sqlalchemy.engine import SQLAlchemyEngineBase
-from gtoolkit.db.orm.sqlalchemy.methods import SQLAlchemyMethodsBase
+from gtoolkit.db.orm.sqlalchemy.methods import SQLAlchemyMethodsBase, BaseModel
 
 
 class MysqlSQLAlchemyMethods(SQLAlchemyMethodsBase):
